@@ -17,7 +17,7 @@
   [theanimator  appendFramesFromFile:"toto.png" xOffest:0 yOffset:0
 		  interval:100 xUnit:48 ];
   [self add:vbox ];
-  [vbox pack_start:theanimator doExpand:FALSE doFill:TRUE doPadding:2];
+  [vbox pack_start:theanimator :FALSE :TRUE :2];
   [theanimator setLoopType:GNOME_ANIMATOR_LOOP_PING_PONG];
   
   //[theanimator start];
