@@ -39,29 +39,28 @@ GnomeUIInfo mainmenu[] = {
 
 	[self connect:"apply"];
 
-	button = [[Gtk_Button new] initWithLabel:_("Click me!")];
+	button = [[Gtk_Button alloc] initWithLabel:_("Click me!")];
 	[button connectObj:"clicked" :self];
 
 	[self append_page:[button show]
-		:[[[Gtk_Label new] initWithLabel:_("Page #1")] show]];
+		:[[[Gtk_Label alloc] initWithLabelInfo:_("Page #1")] show]];
 
-	button = [[Gtk_Button new] initWithLabel:_("Button Fun")];
+	button = [[Gtk_Button alloc] initWithLabel:_("Button Fun")];
 	[button connectObj:"clicked" :self];
 
 	[self append_page:[button show]
-		:[[[Gtk_Label new] initWithLabel:_("Page #2")] show]];
+		:[[[Gtk_Label alloc] initWithLabelInfo:_("Page #2")] show]];
 
-	button = [[[Gtk_Button new] initWithLabel:_("Button1")] show];
+	button = [[[Gtk_Button alloc] initWithLabel:_("Button1")] show];
 	[button connectObj:"clicked" :self];
-	[button connectObjMethod:"clicked" :self
-:@selector(buttonClicked1:)];
+	[button connectObjMethod:"clicked" :self :@selector(buttonClicked1:)];
 
 	/* This button is special, it connects to its own callback and also
 the generic clicked so it also affects the "apply" signal in the property
 box. cool. useful? no :P -Michael */
 
 	[self append_page:[button show]
-		:[[[Gtk_Label new] initWithLabel:_("Page #3")] show]];
+		:[[[Gtk_Label alloc] initWithLabelInfo:_("Page #3")] show]];
 
 	[self show];
 
@@ -126,56 +125,55 @@ id myapp;
 
 	vbox = [[Gtk_VBox new] show];
 	
-	label = [[[Gtk_Label new] initWithLabel:_("GNOME is cool. yup.")] show];
-	button = [[[Gtk_Button new] initWithLabel:_("Font Selection Test")] show];
+	label = [[[Gtk_Label alloc] initWithLabelInfo:_("GNOME is cool. yup.")] show];
+	button = [[[Gtk_Button alloc] initWithLabel:_("Font Selection Test")] show];
 	[button connectObj:"clicked" :self];
 
-	[vbox pack_start:label doExpand:TRUE doFill:TRUE doPadding:5];
-	[vbox pack_start:button doExpand:TRUE doFill:TRUE doPadding:5];
+	[vbox pack_start:label :TRUE :TRUE :5];
+	[vbox pack_start:button :TRUE :TRUE :5];
 
 	button = [[[Gnome_StockButton alloc] initStock:GNOME_STOCK_PIXMAP_PREFERENCES] show];
-	[vbox pack_start:button doExpand:TRUE doFill:TRUE doPadding:5];
+	[vbox pack_start:button :TRUE :TRUE :5];
 
 	vbox2 = [[Gtk_HBox new] show];
-	[vbox pack_start:vbox2 doExpand:TRUE doFill:TRUE doPadding:5];
+	[vbox pack_start:vbox2 :TRUE :TRUE :5];
 
 	pix = [[Gnome_Stock alloc] initWithImage:myapp :GNOME_STOCK_PIXMAP_PREFERENCES];
-	[vbox2 pack_start:[pix show] doExpand:TRUE doFill:TRUE doPadding:5];
+	[vbox2 pack_start:[pix show] :TRUE :TRUE :5];
 
 	pix = [[Gnome_Stock alloc] initWithImage:myapp :GNOME_STOCK_PIXMAP_BOOK_GREEN];
-	[vbox2 pack_start:[pix show] doExpand:TRUE doFill:TRUE doPadding:5];
+	[vbox2 pack_start:[pix show] :TRUE :TRUE :5];
 
 	pix = [[Gnome_Stock alloc] initWithImage:myapp :GNOME_STOCK_PIXMAP_MAIL];
-	[vbox2 pack_start:[pix show] doExpand:TRUE doFill:TRUE doPadding:5];
+	[vbox2 pack_start:[pix show] :TRUE :TRUE :5];
 
-	frame = [[[Gtk_Frame new] initWithLabel:_("connectObjMethod")] show];
-	[vbox pack_start:frame doExpand:TRUE doFill:TRUE doPadding:5];
+	frame = [[[Gtk_Frame alloc] initWithFrameInfo:_("connectObjMethod")] show];
+	[vbox pack_start:frame :TRUE :TRUE :5];
 
 	vbox2 = [[Gtk_HBox new] show];
 	[frame add:vbox2];
 
-	button = [[[Gtk_Button new] initWithLabel:_("Button1")] show];
+	button = [[[Gtk_Button alloc] initWithLabel:_("Button1")] show];
 	[button connectObjMethod:"clicked" :self :@selector(buttonClicked1:)];
-	[vbox2 pack_start:button doExpand:TRUE doFill:TRUE doPadding:5];
+	[vbox2 pack_start:button :TRUE :TRUE :5];
 
-	button = [[[Gtk_Button new] initWithLabel:_("Button2")] show];
+	button = [[[Gtk_Button alloc] initWithLabel:_("Button2")] show];
 	[button connectObjMethod:"clicked" :self :@selector(buttonClicked2:)];
-	[vbox2 pack_start:button doExpand:TRUE doFill:TRUE doPadding:5];
+	[vbox2 pack_start:button :TRUE :TRUE :5];
 
-	button = [[[Gtk_Button new] initWithLabel:_("Button3")] show];
+	button = [[[Gtk_Button alloc] initWithLabel:_("Button3")] show];
 	[button connectObjMethod:"clicked" :self :@selector(buttonClicked3:)];
-	[vbox2 pack_start:button doExpand:TRUE doFill:TRUE doPadding:5];
-
+	[vbox2 pack_start:button :TRUE :TRUE :5];
 
 	vbox2 = [[Gtk_HBox new] show];
-	[vbox pack_start:vbox2 doExpand:TRUE doFill:TRUE doPadding:5];
-	button = [[[Gtk_Button new] initWithLabel:_("Show a Great Canvas")] show];
+	[vbox pack_start:vbox2 :TRUE :TRUE :5];
+	button = [[[Gtk_Button alloc] initWithLabel:_("Show a Great Canvas")] show];
 	[button connectObjMethod:"clicked" :self :@selector(buttonClickedForCanvas:)];
-	[vbox2 pack_start:button doExpand:TRUE doFill:TRUE doPadding:5];
+	[vbox2 pack_start:button :TRUE :TRUE :5];
 
-	button = [[[Gtk_Button new] initWithLabel:_("Show a Great AntiAliased Canvas")] show];
+	button = [[[Gtk_Button alloc] initWithLabel:_("Show a Great AntiAliased Canvas")] show];
 	[button connectObjMethod:"clicked" :self :@selector(buttonClickedForAACanvas:)];
-	[vbox2 pack_start:button doExpand:TRUE doFill:TRUE doPadding:5];
+	[vbox2 pack_start:button :TRUE :TRUE :5];
 
 	[self create_menus:mainmenu];
 	[self set_contents:vbox];
