@@ -10,10 +10,14 @@
 #include <obgtk/obgtk.h>
 
 #include <obgnome/obgnomeAbout.h>
+#include <obgnome/obgnomeAnimator.h>
 #include <obgnome/obgnomeApp.h>
+#include <obgnome/obgnomeAppBar.h>
 #include <obgnome/obgnomeAppWin.h>
 #include <obgnome/obgnomeCalculator.h>
+#include <obgnome/obgnomeColorPicker.h>
 #include <obgnome/obgnomeDateEdit.h>
+#include <obgnome/obgnomeDEntryEdit.h>
 #include <obgnome/obgnomeDialog.h>
 #include <obgnome/obgnomeEntry.h>
 #include <obgnome/obgnomeFileEntry.h>
