@@ -1,8 +1,8 @@
 #ifndef OBGNOME_APP_WIN_H
 #define OBGNOME_APP_WIN_H 1
 
+#include <gnome.h>
 #include "obgtk/obgtk.h"
-#include "gnome.h"
 
 @interface Gnome_AppWin : Gtk_Window
 {
@@ -12,7 +12,7 @@
      not by just simply assigning to them */
   Gtk_Toolbar *toolbar;
   Gtk_MenuBar *menubar;
-  Gtk_Widget *contents;
+  Gtk_Widget *contents, *statusbar;
 }
 - initWithAppWinInfo:(char *)name :(char*)title;
 - castGnomeApp:(GnomeApp *) castitem;
@@ -26,11 +26,10 @@
    to 'self' (make sure that it takes the correct # of params
    for the 'clicked' signal from Gtk) */
 - create_toolbar:(GnomeUIInfo *) tbinfo;
-- set_menus:(Gtk_MenuBar *) setmenubar;
-- set_toolbar:(Gtk_Toolbar *) settoolbar;
-- set_contents:(Gtk_Widget *) setcontents;
-- set_menubar_position:(GnomeAppWidgetPositionType) pos_menubar;
-- set_toolbar_position:(GnomeAppWidgetPositionType) pos_toolbar;
+- set_menus:(id) setmenubar;
+- set_toolbar:(id) settoolbar;
+- set_contents:(id) setcontents;
+- set_statusbar:(id) setstatusbar;
 @end
 
 #endif /* OBGNOME_APP_WIN_H */
