@@ -11,7 +11,8 @@
 - castGnomeDialog:(GnomeDialog *) castitem;
 
 /* Arguments: Title and button names, then NULL */
-- initWithDialogInfo:(const gchar *) title, ...;
+/* call it directly, then pass it to [[Gnome_Dialog alloc] castGnomeDialog:foo]
+   - initWithDialogInfo:(const gchar *) title, ...; */
 
 /* Connect to the "clicked" signal of a single button */
 - button_connect:(gint) button 
