@@ -2,14 +2,6 @@
 #include "obgnomeDialog.h"
 
 @implementation Gnome_Dialog
-- initWithDialogInfo:(const gchar*) title, ...
-{
-  va_list ap;
-  va_start(ap, title);
-
-  return [self castGnomeDialog:GNOME_DIALOG(gnome_dialog_new(title, ap))];
-}
-
 - castGnomeDialog:(GnomeDialog *) castitem
 {
   gnomedialog = castitem;
