@@ -28,8 +28,9 @@
 @public
 GnomeMessageBox *gnomemessagebox;
 }
-- initWithMessageBoxInfo:(const gchar *) message
-                        :(const gchar *) messagebox_type, ...;
+/* Same as in obgnomeDialog.h */
+/* - initWithMessageBoxInfo:(const gchar *) message
+                        :(const gchar *) messagebox_type, ...; */
 - castGnomeMessageBox:(GnomeMessageBox *) castitem;
 @end
 
