@@ -33,12 +33,9 @@
   [[btnQuit connectObj:"clicked" :self] show];
   [btnQuit connectObj:"button_press_event" :self];
 
-  winMain = [[Gtk_Window alloc] initWithWindowType:GTK_WINDOW_TOPLEVEL];
+  winMain = [[Gtk_Window alloc] initWithWindowInfo:GTK_WINDOW_TOPLEVEL];
 	  
-  [[[winMain
-      init]
-     add:btnQuit]
-    show];
+  [[winMain add:btnQuit] show];
   [winMain signal_connect:"delete_event"
 	   signalFunc:gtk_main_quit funcData:NULL];
   return self;
