@@ -1,37 +1,26 @@
 #include "obgtkButton.h"
 
 @implementation Gtk_Button
-- castGtkButton:(GtkButton *) castitem
+
+- castGtkButton : (GtkButton *) castitem
 {
   gtkbutton = castitem;
-  return [super castGtkContainer:GTK_CONTAINER(castitem)];
+  return [super castGtkBin:GTK_BIN(castitem)];
 }
 
-- init
++ (id) makeGtkButton : (GtkButton *) castitem
 {
-  return [self castGtkButton:GTK_BUTTON(gtk_button_new())];
+  id retval;
+  retval = [[Gtk_Object class] getObjectForGtkObject:GTK_OBJECT(castitem)];
+  if(!retval && castitem)
+    retval = [[self alloc] castGtkButton:castitem];
+
+  return retval;
 }
 
-- initWithLabel:(gchar *) label
+- leave
 {
-  return [self castGtkButton:GTK_BUTTON(gtk_button_new_with_label(label))];
-}
-
-- pressed
-{
-  gtk_button_pressed(gtkbutton);
-  return self;
-}
-
-- released
-{
-  gtk_button_released(gtkbutton);
-  return self;
-}
-
-- clicked
-{
-  gtk_button_clicked(gtkbutton);
+  gtk_button_leave(gtkbutton);
   return self;
 }
 
@@ -41,9 +30,45 @@
   return self;
 }
 
-- leave
+- clicked
 {
-  gtk_button_leave(gtkbutton);
+  gtk_button_clicked(gtkbutton);
   return self;
 }
+
+- (GtkReliefStyle) get_relief
+{
+  return gtk_button_get_relief(gtkbutton);
+}
+
+- initWithLabel
+ : (const gchar *) label
+{
+  return [self castGtkButton:GTK_BUTTON(gtk_button_new_with_label(label))];
+}
+
+- released
+{
+  gtk_button_released(gtkbutton);
+  return self;
+}
+
+- init
+{
+  return [self castGtkButton:GTK_BUTTON(gtk_button_new())];
+}
+
+- pressed
+{
+  gtk_button_pressed(gtkbutton);
+  return self;
+}
+
+- set_relief
+ : (GtkReliefStyle) newstyle
+{
+  gtk_button_set_relief(gtkbutton, newstyle);
+  return self;
+}
+
 @end
