@@ -1,12 +1,19 @@
 #ifndef OBGTK_HSCROLLBAR_H
 #define OBGTK_HSCROLLBAR_H 1
-
-#include <obgtk/obgtkScrollbar.h>
+#include <obgtk/obgtkWidget.h>
 #include <obgtk/obgtkAdjustment.h>
+#include <obgtk/obgtkScrollbar.h>
 #include <gtk/gtkhscrollbar.h>
 
 @interface Gtk_HScrollbar : Gtk_Scrollbar
-- initWithGtkAdjustment:(id) gtk_adjustment;
+{
+@public
+  GtkHScrollbar *gtkhscrollbar;
+}
+- castGtkHScrollbar : (GtkHScrollbar *) castitem;
++ (id)makeGtkHScrollbar : (GtkHScrollbar *) castitem;
+- initWithHScrollbarInfo
+ : (id) adjustment;
 @end
 
 #endif /* OBGTK_HSCROLLBAR_H */
