@@ -1,62 +1,47 @@
 #include "obgtkMenuItem.h"
-#include <obgtk/obgtkMenu.h>
 
 @implementation Gtk_MenuItem
-- castGtkMenuItem:(GtkMenuItem *) castitem
+
+- castGtkMenuItem : (GtkMenuItem *) castitem
 {
   gtkmenuitem = castitem;
   return [super castGtkItem:GTK_ITEM(castitem)];
 }
 
-- init
++ (id) makeGtkMenuItem : (GtkMenuItem *) castitem
 {
-  return [self castGtkMenuItem:GTK_MENU_ITEM(gtk_menu_item_new())];
+  id retval;
+  retval = [[Gtk_Object class] getObjectForGtkObject:GTK_OBJECT(castitem)];
+  if(!retval && castitem)
+    retval = [[self alloc] castGtkMenuItem:castitem];
+
+  return retval;
 }
 
-- initWithLabel:(gchar *) label
+- initWithLabel
+ : (const gchar *) label
 {
   return [self castGtkMenuItem:GTK_MENU_ITEM(gtk_menu_item_new_with_label(label))];
 }
 
-- set_submenu:(Gtk_Menu *) submenu
+- configure
+ : (gint) show_toggle_indicator
+ : (gint) show_submenu_indicator
 {
-  gtk_menu_item_set_submenu(gtkmenuitem, submenu->gtkwidget);
+  gtk_menu_item_configure(gtkmenuitem, show_toggle_indicator, show_submenu_indicator);
   return self;
 }
 
-- set_placement:(GtkSubmenuPlacement) placement
+- set_placement
+ : (GtkSubmenuPlacement) placement
 {
   gtk_menu_item_set_placement(gtkmenuitem, placement);
   return self;
 }
 
-#ifndef GTK_HAVE_FEATURES_1_1_0
-- accelerator_size
+- init
 {
-  gtk_menu_item_accelerator_size(gtkmenuitem);
-  return self;
-}
-
-- accelerator_text:(gchar *)buffer
-{
-  gtk_menu_item_accelerator_text(gtkmenuitem, buffer);
-  return self;
-}
-#endif
-
-- configure     :(gint)show_toggle_indicator
- indicateSubmenu:(gint)show_submenu_indicator
-{
-  gtk_menu_item_configure(gtkmenuitem,
-			  show_toggle_indicator,
-			  show_submenu_indicator);
-  return self;
-}
-
-- select
-{
-  gtk_menu_item_select(gtkmenuitem);
-  return self;
+  return [self castGtkMenuItem:GTK_MENU_ITEM(gtk_menu_item_new())];
 }
 
 - deselect
@@ -65,9 +50,11 @@
   return self;
 }
 
-- activate
+- set_submenu
+ : (id) submenu
 {
-  gtk_menu_item_activate(gtkmenuitem);
+  g_return_val_if_fail([submenu isKindOf: [Gtk_Widget class]], 0);
+  gtk_menu_item_set_submenu(gtkmenuitem, ((Gtk_Widget *)submenu)->gtkwidget);
   return self;
 }
 
@@ -77,4 +64,22 @@
   return self;
 }
 
+- remove_submenu
+{
+  gtk_menu_item_remove_submenu(gtkmenuitem);
+  return self;
+}
+
+- select
+{
+  gtk_menu_item_select(gtkmenuitem);
+  return self;
+}
+
+- activate
+{
+  gtk_menu_item_activate(gtkmenuitem);
+  return self;
+}
+
 @end
