@@ -1,25 +1,21 @@
 #include "obgtkRuler.h"
 
 @implementation Gtk_Ruler
-- castGtkRuler:(GtkRuler *)castitem
+
+- castGtkRuler : (GtkRuler *) castitem
 {
   gtkruler = castitem;
   return [super castGtkWidget:GTK_WIDGET(castitem)];
 }
 
-- set_metric:(GtkMetricType) metric
++ (id) makeGtkRuler : (GtkRuler *) castitem
 {
-  gtk_ruler_set_metric(gtkruler, metric);
-  return self;
-}
+  id retval;
+  retval = [[Gtk_Object class] getObjectForGtkObject:GTK_OBJECT(castitem)];
+  if(!retval && castitem)
+    retval = [[self alloc] castGtkRuler:castitem];
 
-- set_range:(gfloat) lower
-      Upper:(gfloat) upper
-   Position:(gfloat) position
-    sizeMax:(gfloat) max_size
-{
-  gtk_ruler_set_range(gtkruler, lower, upper, position, max_size);
-  return self;
+  return retval;
 }
 
 - draw_ticks
@@ -28,9 +24,27 @@
   return self;
 }
 
+- set_metric
+ : (GtkMetricType) metric
+{
+  gtk_ruler_set_metric(gtkruler, metric);
+  return self;
+}
+
+- set_range
+ : (gfloat) lower
+ : (gfloat) upper
+ : (gfloat) position
+ : (gfloat) max_size
+{
+  gtk_ruler_set_range(gtkruler, lower, upper, position, max_size);
+  return self;
+}
+
 - draw_pos
 {
   gtk_ruler_draw_pos(gtkruler);
   return self;
 }
+
 @end
